from distutils.core import setup
setup(
    name ='anminnester',
    version ='1.2.0',
    py_modules =['anminnester'],
    author ='anmin',
    author_email= '1159248869@qq.com',
    url ='http://www.headfirstlabs.com',
    description ='A simple printer of nested lists,2020.1.14 16:25',
)